\\ Copyright 2022 Kevin Ryde
\\
\\ This file is free software; you can redistribute it and/or modify it
\\ under the terms of the GNU General Public License as published by the Free
\\ Software Foundation; either version 3, or (at your option) any later
\\ version.
\\
\\ This file is distributed in the hope that it will be useful, but
\\ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
\\ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
\\ for more details.
\\
\\ You should have received a copy of the GNU General Public License along
\\ with this file.  See the file COPYING.  If not, see
\\ <http://www.gnu.org/licenses/>.

default(recover,0);
default(strictargs,1);

read("../OEIS-data.gp");  \\ check multiple reads
read("../OEIS-data.gp");
read("../OEIS-data.gp");

option_verbose = 0;

print("HOME is:");
system("printenv HOME");

\\ Whether to print test progress and names.
if(option_verbose=='option_verbose, option_verbose=0);


\\-----------------------------------------------------------------------------
\\ Test Helpers

check_count = 0;
check_equal(got,want,name="") =
{
  check_count++;
  if(got != want,
     print("wrong "name);
     print("got  "got);
     print("want "want);     quit(1));
  if(option_verbose,
     print("ok "check_count" "name));
}


\\=============================================================================
\\-----------------------------------------------------------------------------
\\ OEIS_name()

{
  check_equal(OEIS_name("A810000"),
              "Test sequence 810000.");
}

\\-----------------------------------------------------------------------------
\\ OEIS_data()

{
  \\ A810000 internal.txt only
  check_equal(OEIS_data("A810000"),
              [5830, 827, 999],
              "OEIS_data() .internal.txt");

  \\ A700001 stripped only
  check_equal(OEIS_data("A700001"),
              [7,9,9,9,9,9,7,9,9,9,9,9],
              "OEIS_data() A700001 stripped");

  \\ A700002 stripped and b-file
  check_equal(OEIS_data("A700002"),
              [1,3,8,7,2,1,3],
              "OEIS_data() A700002 stripped");
  check_equal(OEIS_data("A700002",'bfile),
              [1,3,8,7,2,1,3, 100,200,300],
              "OEIS_data() A700002 bfile");

  \\ OEIS/b800000.txt
  check_equal(OEIS_data("A800000",'bfile),
              [1234567, 76543],
             "OEIS_data() 'bfile");

}

\\-----------------------------------------------------------------------------
\\ OEIS_offset()

{
  \\ A800000 internal.txt
  check_equal(OEIS_offset("A800000"), 42);

  \\ A700002 stripped and b-file
  check_equal(OEIS_offset("A700002"), 23,
              "OEIS_offset() A700002 from bfile");
}


\\-----------------------------------------------------------------------------
\\ OEIS_offset_and_data()

{
  check_equal(OEIS_offset_and_data("A800000",'bfile),
             [42, [1234567, 76543]]);

  check_equal(OEIS_offset_and_data("A810000"),
             [7, [5830, 827, 999]]);

  \\ A700002 stripped and b-file
  check_equal(OEIS_offset_and_data("A700002"), 
              [23, [1,3,8,7,2,1,3]],
              "OEIS_offset_and_data() A700002 stripped and bfile");
  check_equal(OEIS_offset_and_data("A700002",'bfile),
              [23, [1,3,8,7,2,1,3, 100,200,300]],
              "OEIS_offset_and_data() A700002 bfile");
}


\\-----------------------------------------------------------------------------
\\ OEIS_data_func()

{
  my(func=OEIS_data_func("A800000",'bfile));
  check_equal(func(42),1234567);
  check_equal(func(43), 76543);
  check_equal(iferr(func(41);0, e, Str(e)),
    "error(\"user error: A800000 is for n>=42\")",
              "OEIS_data_func() too small");
  check_equal(iferr(func(44);0, e, Str(e)),
    "error(\"user error: A800000 data extends only to n<=43\")",
              "OEIS_data_func() too big");
}

\\-----------------------------------------------------------------------------
\\ OEIS_data_gf()

{
  \\ OEIS/A810000.internal.txt
  my(got=OEIS_data_gf("A810000"));
  check_equal(got,
              5830*x^7 + 827*x^8 + 999*x^9 + O(x^10),
              "OEIS_data_gf() .internal.txt");
  check_equal(type(got), "t_SER");
}


\\-----------------------------------------------------------------------------
\\ OEIS_INTERNAL_validate_anum()

OEIS_INTERNAL_validate_anum("A000120");
OEIS_INTERNAL_validate_anum("A123456");
OEIS_INTERNAL_validate_anum("A999999");
OEIS_INTERNAL_validate_anum('A999999 );

{
  my(samples=["A999 999", "-1", "$x"]);
  for(i=1,#samples,
     my(anum=samples[i],
        got=iferr(OEIS_INTERNAL_validate_anum();'good, e, 'bad));
     check_equal(got,'bad));
}  


\\-----------------------------------------------------------------------------


\\==============================================================================
\\ test-symbols.txt is all symbols appearing in OEIS-data.gp.

\\ {
\\   my(test_symbols=readstr("test-symbols.txt"));
\\   check_equal(#test_symbols>0,1);
\\   for(test_i=1,#test_symbols,
\\      my(test_symbol=test_symbols[test_i]);
\\      check_equal(eval(test_symbol),
\\                  eval(Str("'"test_symbol)),
\\                  Str("leftover global variable: "test_symbol)));
\\ }

\\-----------------------------------------------------------------------------
{
  check_equal(anum,anum);
  check_equal(n,'n);
  check_equal(offset,'offset);
  check_equal(allow,'allow);

  printf("total %d tests in %.1f seconds\n",
         check_count, gettime() /1000);
}

\\-----------------------------------------------------------------------------
\\ Local variables:
\\ compile-command: "make test"
\\ End:
